@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::GithubMeta;
 BEGIN {
-  $Dist::Zilla::Plugin::GithubMeta::VERSION = '0.14';
+  $Dist::Zilla::Plugin::GithubMeta::VERSION = '0.16';
 }
 
 # ABSTRACT: Automatically include GitHub meta information in META.yml
@@ -85,7 +85,7 @@ sub metadata {
 
   return unless $self->_has_user and $self->_has_repo;
 
-  my $gh_url  = sprintf 'http://github.com/%s/%s', $self->user, $self->repo;
+  my $gh_url  = sprintf 'https://github.com/%s/%s', $self->user, $self->repo;
   my $bug_url = "$gh_url/issues";
 
   my $home_url = $self->homepage ? $self->homepage->as_string : $gh_url;
@@ -144,7 +144,7 @@ Dist::Zilla::Plugin::GithubMeta - Automatically include GitHub meta information
 
 =head1 VERSION
 
-version 0.14
+version 0.16
 
 =head1 SYNOPSIS
 
